<?php

/************************************************************
*
*  Easy Custom Event Tickets [REV:1.8] 
*
* 
************************************************************/


/* Empêche l'utilisateur public d'accéder directement aux fichiers .php via l'URL
et garantit que les fichiers du plugin seront exécutés uniquement dans l'environnement WordPress.*/
defined( 'ABSPATH' ) || die();


/******************************
 * Setting up the admin pages
 ******************************/

// On utilise le hook admin menu pour ajouter notre menu 
// pour la page de réglages du plugin
add_action( 'admin_menu', 'ecet_menu_items' );



 /* On enregistre notre nouvel élément de menu*/
 function ecet_menu_items() {
    // On crée un élément de menu de niveau supérieur
    $hookname = add_menu_page(
        __( 'Easy Custom Event Tickets Settings', 'custom-event-tickets' ),  // Page title , Text Domain(pour la traduction)
        __( 'ECET Settings', 'custom-event-tickets' ),  // Menu title, Text Domain(pour la traduction)
        'manage_options',                     // Capabilities (Capacités)
        'ecet_settings_page',              // Slug
        'ecet_settings_page_markup',       // Display callback (fonction permettant l'affichage du contenu de la page de réglages)
        'dashicons-editor-table',          // Icon
        66                                 // Priority/position. Just after 'Plugins'
    );
}



//Mettre en file d'attente le script et le style wp-color-picker 
//le fichier PHP dans lequel on écrit ces lignes se trouve dans le sous-dossier js du plugin
//On utilise donc pour l'URL du script: dirname(__FILE__) au lieu de  __FILE__  si cette fonction était dans le fichier principal du plugin
// Mon plugin a maintenant un ecet-script.js fichier qui a été déclaré en tant que dépendance de wp-color-picker
add_action( 'admin_enqueue_scripts', 'ecet_enqueue_color_picker' );

function ecet_enqueue_color_picker( $hook_suffix ) {
    
    wp_enqueue_style( 'wp-color-picker' );
	// paramètre: handle,URL script, dépendance, Version , True: script inséré dans le footer
    wp_enqueue_script( 'my-script-handle', plugins_url('js/ecet-script.js', dirname(__FILE__) ), array( 'wp-color-picker' ), false, true );
}


/* Fonction de rappel qui va contenir le balisage de la page et donc nos réglages 
   on utilise la classe CSS de wrap, qui est utilisée un peu partout dans l’administration de WordPress 
   - On Affiche le Titre de la page de réglages
   - On place un élément <form> qui va pointer vers options.php , et qui va envoyer ses données en POST.
   - La fonction settings_fields() prend un unique paramètre correspondant au nom d’un groupe de réglages 
     (définit dans setting.php fonction: ecet_multiple_setting() )
     settings_fields() va afficher les champs cachés nécessaires pour traiter notre formulaire:
	 les champs nonce, referer, action, et option_page  
   - La fonction do_settings_sections() permet boucler sur nos sections et afficher les champs de réglages correspondants.
     elle prend en argument le slug de la page de réglages définit dans la fonction: ecet_menu_items() 
   - Le bouton de soumission du formulaire
*/
function ecet_settings_page_markup(){
	
    ?>
	    
        <div class="wrap">
		
            <h1><?php echo esc_html_e( get_admin_page_title(),'custom-event-tickets' ); ?></h1> <!-- On Affiche le Titre de la page de réglages avec le text domain donné en référence pour la traduction -->
			
			<form action="options.php" method="POST">
			
				<?php
                    settings_fields( 'settings_ecet' );// afficher les champs nonce, referer, action, et option_page( en paramètre le settings group de réglage définit dans le fichier multiple-setting.php) 
					do_settings_sections( 'ecet_settings_page' );// permet  de boucler sur nos sections et afficher les champs de réglages correspondants ( en paramètre le slug de la page de réglages)
					submit_button( __( 'Save Settings', 'custom-event-tickets' ));// le bouton de soumission du formulaire( Enregister les paramètres) 
                ?>
            
			</form>
			
        </div>
		
    <?php
	
}